=================================
AiiDA-FLEUR Calculations
=================================

AiiDA-FLEUR plugin consists of three main parts:

#. FLEUR input generator (:ref:`inpgen_plugin`)
#. FLEUR code (:ref:`fleurcode_plugin`)

Fleur input generator represents inpgen code, FLEUR code represents fleur and fleur_MPI codes.

Other codes from the Fleur family (GFleur) or which are built on top of FLEUR (Spex) are
not supported yet.

.. toctree::
    :maxdepth: 4

    inpgen_plugin
    fleurcode_plugin
